@@ -873,7 +873,7 @@ class BaseExperiment:
             for metadata in os.listdir(f'{jsonlogdir}/{model_type_dir}'):
                 for version in os.listdir(f'{jsonlogdir}/{model_type_dir}/{metadata}'):
                     for file in os.listdir(f'{jsonlogdir}/{model_type_dir}/{metadata}/{version}'):
-                        with open(file, "r") as json_file:
+                        with open(f'{jsonlogdir}/{model_type_dir}/{metadata}/{version}/{file}', "r") as json_file:
                             logs = json.load(json_file)
                             val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
                             if best_val is None:
